# Data Models

Pydantic models for representing financial data.

## Assets

::: fundedness.models.assets.Asset

::: fundedness.models.assets.AccountType

::: fundedness.models.assets.LiquidityClass

::: fundedness.models.assets.ConcentrationLevel

## Balance Sheet

::: fundedness.models.assets.BalanceSheet

## Liabilities

::: fundedness.models.liabilities.Liability

## Household

::: fundedness.models.household.Household

::: fundedness.models.household.Person

## Market Model

::: fundedness.models.market.MarketModel

## Simulation Config

::: fundedness.models.simulation.SimulationConfig

## Tax Model

::: fundedness.models.tax.TaxModel
